@@ -25,7 +25,7 @@ typedef enum
     OP_FOLDER              = 4
 } Operation;
 
-#define PID_DIR  "kde-"
+#define PID_DIR  "tde-"
 #define PID_NAME "kdialogd.pid"
 
 static const char * getPidFileName()
