@@ -18,7 +18,7 @@ class TDEConfig;
 
 class KDialogDFileDialog : public KFileDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
@@ -44,7 +44,7 @@ class KDialogDFileDialog : public KFileDialog
 
 class KDialogDDirSelectDialog : public KDirSelectDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
@@ -70,7 +70,7 @@ class KDialogDDirSelectDialog : public KDirSelectDialog
 
 class KDialogDClient : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
@@ -109,7 +109,7 @@ class KDialogDClient : public TQObject
 
 class KDialogD : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
