@@ -238,7 +238,7 @@ static const TQString getFilters(TQFileDialog *dlg, bool scribusSave=false)
                                        end(children.end());
 
             for(; it!=end; ++it)
-                if(::tqqt_cast<TQComboBox *>(*it) && 0==qstrcmp((*it)->name(), "file types"))
+                if(::tqt_cast<TQComboBox *>(*it) && 0==qstrcmp((*it)->name(), "file types"))
                 {
                     TQComboBox    *types=(TQComboBox *)(*it);
                     TQTextOStream str(&filter);
@@ -275,7 +275,7 @@ static TQString getCurrentFileName(TQFileDialog *dlg)
                                        end(children.end());
 
             for(; it!=end; ++it)
-                 if(::tqqt_cast<TQLineEdit *>(*it)) // && 0==qstrcmp((*it)->name(), "name/filter editor"))
+                 if(::tqt_cast<TQLineEdit *>(*it)) // && 0==qstrcmp((*it)->name(), "name/filter editor"))
                     return ((TQLineEdit *)(*it))->text();
         }
     }
